#
# spec file for package frozen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           frozen
Version:        1.2.0
Release:        1.2
Summary:        A header only, constexpr alternative to gperf for C++14 users
License:        Apache-2.0
URL:            https://github.com/serge-sans-paille/%{name}
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#:/%{name}-%{version}.tar.gz
Patch0:         frozen-cmake.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
Header-only library that provides 0 cost initialization for immutable
containers, fixed-size containers, and various algorithms.

%package devel
Summary:        Header files for frozen, an alternative to gperf
Group:          Development/Languages/C and C++
BuildArch:      noarch

%description devel
Header-only library that provides 0 cost initialization for immutable
containers, fixed-size containers, and various algorithms.

This package contains the headers.

%prep
%autosetup -p1

# The previous empty line is allowing buiding on sle12, where autosetup is buggy

%build
%cmake -DBUILD_TESTING=OFF
%cmake_build

%install
%cmake_install

%files devel
%doc README.rst
%license LICENSE
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*
%dir %{_datadir}/cmake/%{name}
%{_datadir}/cmake/%{name}/*

%changelog
* Mon Sep  2 2024 Martin Schreiner <martin.schreiner@suse.com>
- Update to 1.2.0.
  * Fixing "'macro' is not defined" warning, when using clang-tidy
  * Drop a note in the README about the stability of frozen
  * Upgrade catch to v2.13.10
  * Update github action versions
  * Add tests for gcc 13 and clang 15
  * Use ARCH_INDEPENDENT when available
  * Disable testing on compilers no longer part of ubuntu-latest image
  * Support transparent hashing through elsa *and* anna
  * Remove non-standard API that uses custom hasher / comparator
  * Widen the checked compiler version ranges on Linux
  * Split Travis validation across platforms
  * Get rid of travis validation
  * Get rid of appveyor validation
  * Use CMAKE_INSTALL_* dirs from GNUInstallDirs
  * feat: mark map keys as const to meet associative container requirements
  * feat: make frozen::string bidirectionally comparable
  * refactor: allow sorting containers other than bits::carray
  * refactor: change sorting algorithm to use iter_swap to support proxy iterators
  * fix: ensure const bits::cvector can be iterated over
  * refactor: move const and reverse iterator conversion out of storage classes
  * fix: forward const_iterator from underlying container instead of redefining it
  * refactor: initialize carray to content we want
  * fix: include 'defines.h' in elsa_std.h which relies on some of its macros
  * fix: match associative container requirements for comparison predicates
  * improvement: allow empty key comparison and hash functors to occupy no space
  * refactor: use freshly constructed state vars instead of resetting each time
  * fix: allow building tests when the compiler doesn't support C++17
  * improvement: make unused slots in the hash tables equal items' end iterator
  * refactor: use this->find() as replacement for this->lookup()
  * use consistent integer types
  * Fix closure types not being literal types and thus not constexpr-compatible
  * Add c++20 contains to the associative containers
  * Workaround gcc 11 limitation
  * Add test cases suggested by @adamshapiro0
  * Standard implementation for lower_bound/upper_bound/equal_range
  * Suggested changes for nicer checks.
  * Fix boyer-moore going over string iterator end
  * Add more tests for edge cases that would make search go over string iterator end
* Mon Aug  7 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * frozen-cmake.patch
    + lower cmake version requirements in order to allow building on
    sle12sp5
* Thu Jul 13 2023 Danilo Spinella <danilo.spinella@suse.com>
- Initial packaging of version 1.1.1
